# print('Executing expLogbook.py')
# from getComment4File import *
import requests
import urllib.parse
import os
import builtins
import re
from elog.logbook_exceptions import *
import elog
from datetime import datetime
from time import localtime

# disable warnings about ssl verification
from requests.packages.urllib3.exceptions import InsecureRequestWarning
requests.packages.urllib3.disable_warnings(InsecureRequestWarning)


class myLogbook(elog.Logbook):
        
    def getMessage4File(self, filename):
        ids = super().search({'file':filename})
        if len(ids) > 0:
            message, _ , _ = super().read(ids[0])
            return message
        else:
            print("File {} in eLog not found!".format(filename))
            return None

    def getShortMessage4File(self,filename):
        stuff = self.getMessage4File(filename)
        import html2text
        h = html2text.HTML2Text()
        # Ignore converting links from HTML
        h.ignore_links = True
        if stuff: return h.handle(stuff)
        return


##########################################################################################################
# ogf settings:
try:
    from libhreels.eLogCredentials import dummy, unsafe    # Defines User credentials
    logbook = myLogbook('https://labor-ep3.physik.uni-halle.de/HREELS/', user=dummy, password=unsafe)
    print('eLog available!')
    available = True
except:
    available = False




# Testing dielectric models and their surface loss function
import matplotlib.pyplot as plt
import numpy as np
from numpy import real, imag, sqrt
#from scipy.constants import physical_constants

# Thz = 100*physical_constants['speed of light in vacuum'][0] # conversion from cm^-1 to Hz 

def doping2plasmaFrequency(doping,epsInfinity=1.):
    '''Returns the bulk plasma frequency in cm-1 for a doping 
       given by the argument in cm-3.
       Check if eps_Infinity handling is correct.'''
    return np.sqrt(doping)*1.8817885780819758e-06/np.sqrt(epsInfinity)

def doping2surfacePlasma(doping,epsInfinity=1.):
    '''Returns the surface plasma frequency in cm-1 for a doping 
       given by the argument in cm-3'''
    return np.sqrt(doping)*1.8817885780819758e-06/np.sqrt(1+epsInfinity)

def loss(eps):
    return np.imag(1/eps)

def surfaceLoss(eps):
    return np.imag(1/(1+eps))

def reflectivity(eps):  # IR reflectivity
    sq = np.sqrt(eps)
    a =np.abs((sq-1)/(sq+1))
    return a*a

def sigma(eps,w,eps_Infinity=1):       # Complex conductivity 
    return np.imag((eps-eps_Infinity)*w)

def plotDielectrics(x,eps):
    fig, axs = plt.subplots(3, 1, sharex=True, figsize=(6,6))
    axs[0].plot(x, -np.imag(eps), label='-Im $\epsilon (\omega )$')
    axs[0].plot(x, np.real(eps), label='Re $\epsilon (\omega )$')    
    axs[0].legend()
    axs[0].set_ylabel('Dielectric Function')

    axs[1].plot(x, surfaceLoss(eps), linestyle='-')    
    axs[1].set_ylabel('Surface Loss Function')
    axs[1].set_ylim([0,None])

    axs[2].plot(x, reflectivity(eps))
    axs[2].set_ylabel('Reflectivity')
    axs[2].set_xlabel('Frequency')
    axs[2].set_ylim([0,1])
    axs[0].set_xlim(left=0, right=max(x))

    plt.show()
class oscillator:
    def __init__(self, wTO, wLO, gammaTO=20, gammaLO=20):
        self.wTO = wTO
        self.wLO = wLO
        self.gammaTO = gammaTO
        self.gammaLO = gammaLO

    def eps(self,w):
        nom = self.wLO*self.wLO - w*w + 1j*self.gammaLO*w
        denom = self.wTO*self.wTO - w*w + 1j*self.gammaTO*w
        return nom/denom

    def __call__(self, w):
        return self.eps(w)

class simpleOsci(oscillator):
    def __init__(self, wTO, Q, gammaTO=20):
        self.wTO = wTO
        self.Q = Q
        self.gammaTO = gammaTO

    def eps(self,w):
        nom = self.wTO*self.wTO*self.Q
        denom = self.wTO*self.wTO - w*w + 1j*self.gammaTO*w
        return nom/denom

class drude:
    '''Returns the additive Drude response with plasma frequency and damping as parameters. Note that for the
    full dielctric response, this Drude contribution has to be added to eps_infinity and any phonon
    contribution.
    '''
    def __init__(self, wPL, gamma):
        self.wPL = wPL
        self.gamma = gamma

    def eps(self,w):
        # Starting from libhreels version 1.1.4, it has been corrected:
        return -(self.wPL*self.wPL)/(w*w - 1j*self.gamma*w)
    

    def __call__(self, w):
        return self.eps(w)

class drude2:
    '''Returns the additive extended Drude response with three arguments: plasma frequency and two damping
    parameters. The first damping parameter is the plasma damping and the second the damping at frequency
    zero. Note that for the full dielectric response, this Drude contribution has to be added to eps_infinity
    and any phonon contribution. 

        eps = drude2(omega_p, gamma_p, gamma_0)
    '''
    def __init__(self, omega_p, gamma_p, gamma_0=None):
        self.omega_p = omega_p
        self.gamma_p = gamma_p
        if gamma_0:
            self.gamma_0 = gamma_0
        else:
            self.gamma_0 = gamma_p

    def eps(self,w):
        newW = np.where(w==0, 0.000567894, w)   # Avoid zeros to avoid devision by zero 
        w = newW
        return -((self.omega_p**2 + 1j*(self.gamma_p-self.gamma_0)*w)/(w*(w - 1j *self.gamma_0)))

    def __call__(self, w):
        return self.eps(w)

def myMain():
    # BaTiO3
    data = [
        [178.6, 8.02, 3.09800E-02],
        [270.6, 24.00, 10.0800E-02],
        [522.9, 1.20, 6.97200E-02]]
    # Width (3rd parameter) is given in fraction of TO frequency

    oscis = [simpleOsci(TO, Q, f*TO) for (TO, Q, f) in data]
        
    x = np.linspace(5,1000,num=1200)
    epsInfinity = 5.25
    eps = epsInfinity
    for each in oscis:
        eps += each(x)

    # Now add Drude contribution:
    eps += drude2(1200,60)(x)
    plotDielectrics(x, eps)

if __name__ == '__main__':
	myMain()



import numpy as np
from matplotlib import pyplot as plt

def findPeriod(list, period):
    '''For a list of times (relative to a sync pulse) calculate the average time deviation squared.  
    '''
    residuum = []
    sum_residuum = 0
    for each in list:
        r = each % period
        residuum.append(r)
        sum_residuum += r
    av_res = sum_residuum / len(list)
    deviation = 0
    for res in residuum:
        deviation += (res - av_res)**2
    deviation /= (len(residuum)*period**2)
    return deviation, av_res

def makeTimeRelative(times, durations):
    list = []
    synced = False
    t_zero = 0
    for each in pulses:
        if synced:
            list.append(pulses[each][0]-t_zero)
        if 9000 < pulses[each][2] < 9800:
            print("synced")
            t_zero = pulses[each][0]
            synced = True
    return list

data = []       # read dat from file [[time in microsec, low duration, high duration], [...], ...]
with open("data433_Signal2.txt", 'r') as f:
    for line in f:
        data.append([int(each) for each in line.split(',')])

sumOn = 0; sumOff = 0
for pulse in data[1:]:
    sumOn += pulse[2]
    sumOff += pulse[1]
sumOn /= len(data)
sumOff /= len(data)

print("Average on and off times:", sumOn, sumOff)
